Learn R Programming

MonoPhy (version 1.3.2)

MonoPhy-package: Explore Monophyly of Taxonomic Groups in a Phylogeny.

Description

Requires rooted phylogeny as input and creates a table of taxa, their monophyly-status, which other taxa cause problems in monophyly (as intruders or outliers) etc. Different information can be extracted from the output and a plot function allows visualization of the results in a number of ways.

Arguments

Author

Orlando Schwery, Brian O'Meara, Peter Cowman

Maintainer: Orlando Schwery <oschwery@vols.utk.edu>

Details

Package:MonoPhy
Type:Package
Version:1.3
Date:2021-02-15
License:GPL-3

The package allows to explore monophyly in phylogenetic trees in a quick and simple way. AssessMonophyly determines whether taxa in a phylogeny are monophyletic. CollapseMonophyletics creates a tree objects where monophyletic groups are collapsed, GetSummaryMonophyly extracts a summary table from the results, GetResultMonophyly extracts the main result table, GetIntruderTaxa, GetIntruderTips, GetOutlierTaxa and GetOutlierTips extract names of taxa which interfere with the monophyly of another or the same taxon respectively and GetAncNodes a table of MRCA nodes. PlotMonophyly finally, allows visualizing the results in a couple of different ways.

See Also

AssessMonophyly, CollapseMonophyletics, GetAncNodes, GetIntruderTaxa, GetIntruderTips, GetOutlierTaxa, GetOutlierTips GetResultMonophyly, GetSummaryMonophyly, MonophylyData, PlotMonophyly