Object with saved output of the 'AssessMonophyly' function.
tree
An object of type 'phy', rooted phylogeny (the same which was used to obtain the solution before).
taxlevels
An integer or name corresponding to the desired taxonomic level (i.e. the number of its column in the taxonomy table, not counting the tip names). Default is 1.
ladderize
If TRUE will ladderize tree before collapsing clades. Default is TRUE.
Author
Orlando Schwery, Peter Cowman
Details
Can be used after 'AssessMonophyly' is run to obtain a tree object where all groups that were inferred as monophyletic at a given taxonomic level will be collapsed to single tips and relabeled according to the name of their group. The resulting tree will have the same topology as seen when plotting the original tree with setting 'monocoll=TRUE' in 'PlotMonophyly'.